import { query, create, update, remove } from '../../services/merchant';
import modelExtend from 'dva-model-extend';
import queryString from 'query-string';
import { pageModel } from '../common';
import config from '../../utils/config';
import { checkSearchParams } from '../../utils/utils';

export default modelExtend(pageModel, {
  namespace: 'merchant',

  state: {
    currentItem: {},
    itemLoading: false,
    listLoading: false,
    modalVisible: false,
    modalType: 'create',
  },

  subscriptions: {
    setup({ dispatch, history }) {
      history.listen((location) => {
        if (location.pathname === '/merchant') {
          const payload = checkSearchParams(queryString.parse(location.search));
          dispatch({
            type: 'query',
            payload,
          });
        }
      });
    }
  },

  effects: {
    * query ({ payload = {} }, { call, put }) {
      yield put({ type: 'changeLoading', payload: { listLoading: true }});
      const { data, success } = yield call(query, payload);
      if (success) {
        yield put({
          type: 'querySuccess',
          payload: {
            list: data.list,
            pagination: {
              current: Number(payload.pageNo) || 1,
              pageSize: Number(payload.pageSize) || config.pageSize,
              total: data.totalSize,
            }
          }
        });
      }
      yield put({ type: 'changeLoading', payload: { listLoading: false }});
    },
    * create ({ payload, callback }, { call, put }) {
      const { data, success } = yield call(create, payload);
      if (success) {
        if (callback) callback();
      }
    },
    * update ({ payload, callback }, { call, put }) {
      const { data, success } = yield call(update, payload);
      if (success) {
        yield put({ type: 'hideModal' });
        if (callback) callback();
      }
    },
    * delete ({ payload, callback }, { call, put }) {
      const { data, success } = yield call(remove, payload);
      if (success) {
        if (callback) callback();
      }
    },
    * recover ({ payload, callback }, { call, put }) {
      const { data, success } = yield call(update, payload);
      if (success) {
        if (callback) callback();
      }
    },
  },

  reducers: {
    changeLoading(state, { payload }) {
      return { ...state, ...payload };
    },

    showModal(state, { payload }) {
      return { ...state, ...payload, modalVisible: true };
    },

    hideModal(state) {
      return { ...state, modalVisible: false };
    },
  }
})
