import { message } from 'antd';
import { queryOne, create, update } from '../../services/product';
import pathToRegexp from 'path-to-regexp';
import { Codes } from '../../utils/config';

export default {
  namespace: 'supportDetail',

  state: {
    filters: {},
    operType: 'create',
    currentItem: {},
    supportModalVisible: false,
    resourceModalVisible: false,
    itemLoading: false,
  },

  subscriptions: {
    setup({ dispatch, history }) {
      history.listen(({ pathname, state, ...rest }) => {
        const match = pathToRegexp('/product/support/edit/:pid').exec(pathname);
        if (match) {
          dispatch({ type: 'query', payload: { pid: match[1] } });
          dispatch({ type: 'saveFilters', payload: state });
          dispatch({ type: 'saveOperType', payload: { operType: 'update' } });
        }
        if (pathname === '/product/support/add') {
          dispatch({ type: 'saveFilters', payload: state });
          dispatch({ type: 'saveFilters', payload: state });
          dispatch({ type: 'saveOperType', payload: { operType: 'create' } });
        }
      });
    }
  },

  effects: {
    * query ({ payload }, { call, put }) {
      yield put({ type: 'changeLoading', payload: { itemLoading: true } });
      const { data, success } = yield call(queryOne, payload);
      if (success) {
        yield put({ type: 'querySuccess', payload: data });
      }
      yield put({ type: 'changeLoading', payload: { itemLoading: false } });
    },
    * create ({ payload, callback }, { call, put }) {
      const { data, success } = yield call(create, payload);
      if (success) {
        message.success('创建成功!');
        if (callback) callback();
        yield put({ type: 'initState' });
      }
    },
    * update ({ payload, callback }, { call, put }) {
      const { data, success } = yield call(update, payload);
      if (success) {
        message.success('修改成功!');
        if (callback) callback();
        yield put({ type: 'initState' });
      }
    }
  },

  reducers: {
    changeLoading(state, { payload }) {
      return { ...state, ...payload };
    },
    querySuccess(state, { payload }) {
      return { ...state, currentItem: payload };
    },
    saveFilters(state, { payload: filters }) {
      return { ...state, filters };
    },
    showSupportModal(state, { payload }) {
      return { ...state, ...payload, supportModalVisible: true };
    },
    hideSupportModal(state) {
      return { ...state, supportModalVisible: false };
    },
    showResourceModal(state, { payload }) {
      return { ...state, ...payload, resourceModalVisible: true };
    },
    hideResourceModal(state) {
      return { ...state, resourceModalVisible: false };
    },
    saveSupportList(state, { payload: { supportList } }) {
      const currentItem = { ...state.currentItem, supportList };
      return { ...state, supportModalVisible: false, currentItem };
    },
    saveCoverImg(state, { payload: { coverUrl } }) {
      const currentItem = { ...state.currentItem, coverUrl };
      return { ...state, resourceModalVisible: false, currentItem };
    },
    saveImgList(state, { payload: { imgList } }) {
      const currentItem = { ...state.currentItem, imgList };
      return { ...state, resourceModalVisible: false, currentItem };
    },
    saveOperType(state, { payload }) {
      return { ...state, ...payload };
    },
    initState(state) {
      return { ...state, currentItem: {}, itemLoading: false };
    }
  }
}
