import React, { Component } from 'react';
import { Form, Cascader, Select, Input, Modal, Icon } from 'antd';
import * as city from '../../utils/city';

@Form.create()
export default class CampusModalForm extends Component {

  handleOnOk = () => {
    const { onOk, form, item } = this.props;
    const { validateFields, getFieldsValue } = form;
    validateFields((errors) => {
      if (errors) return;
      const data = { ...getFieldsValue() };

      data.provinceCode = city.provNameToCode(data.cascader[0]);
      data.cityName = data.cascader.slice(1, 3).join(' ');
      delete data.cascader;
      item.id ? data.id = item.id : null;

      onOk(data);
    });
  }

  render() {
    const { item, merchants, onOk, form, ...modalProps } = this.props;
    const { getFieldDecorator } = form;

    const formItemLayout = {
      labelCol: { span: 7 },
      wrapperCol: { span: 14 },
    };

    const modalOpts = { ...modalProps, onOk: this.handleOnOk }

    return (
      <Modal {...modalOpts}>
        <Form layout="horizontal">
          <Form.Item label="渠道名称" hasFeedback {...formItemLayout}>
            {getFieldDecorator('merchantId', {
              rules: [{ required: true, type: 'string', message: "该项为必选项!" }],
              initialValue: item.merchantId,
            })(
              <Select
                showSearch
                allowClear
                placeholder="请选择"
                optionFilterProp="children"
                filterOption={(input, option) => option.props.children.toLowerCase().indexOf(input.toLowerCase()) >= 0}
              >
                {merchants.map(selItem => <Select.Option value={selItem.id} key={selItem.id}>{`${selItem.code}/${selItem.name}`}</Select.Option>)}
              </Select>
            )}
          </Form.Item>
          <Form.Item label="校区地址" hasFeedback {...formItemLayout}>
            {getFieldDecorator('cascader', {
              rules: [
                {
                  required: true,
                  message: '校区地址为必选项！'
                }
              ],
              initialValue: item.provinceCode && [city.provCodeToName(item.provinceCode), ...(item.cityName || '').split(' ')],
            })(<Cascader
              style={{ width: '100%' }}
              options={city.DICT_FIXED}
              placeholder="请选择"
            />)}
          </Form.Item>
          {/*校区编号暂不显示
          <Form.Item label="校区编号：" {...formItemLayout}>
            {getFieldDecorator('code', {
              initialValue: item.code,
            })(<Input disabled={true} placeholder="提交后根据校区地址自动生成"/>)}
          </Form.Item>
          */}
          <Form.Item label="校区名称：" hasFeedback {...formItemLayout}>
            {getFieldDecorator('zoneName', {
              initialValue: item.zoneName,
              rules: [
                {
                  required: true,
                  message: '校区名称为必填项！',
                },
              ],
            })(<Input placeholder="请填写"/>)}
          </Form.Item>
          <Form.Item label="联系人：" hasFeedback {...formItemLayout}>
            {getFieldDecorator('contactName', {
              initialValue: item.contactName,
              rules: [
                {
                  required: true,
                  message: '联系人为必填项！',
                },
              ],
            })(<Input />)}
          </Form.Item>
          <Form.Item label="联系电话：" hasFeedback {...formItemLayout}>
            {getFieldDecorator('mobile', {
              initialValue: item.mobile,
              rules: [
                {
                  required: true,
                  message: '联系电话为必填项！',
                },
              ],
            })(<Input />)}
          </Form.Item>
          <Form.Item label="收货地址" hasFeedback {...formItemLayout}>
            {getFieldDecorator('address', {
              initialValue: item.address,
            })(<Input />)}
          </Form.Item>
          <Form.Item label="银行账户" hasFeedback {...formItemLayout}>
            {getFieldDecorator('bankAccount', {
              initialValue: item.bankAccount,
            })(<Input />)}
          </Form.Item>
          <Form.Item label="开户行名称" hasFeedback {...formItemLayout}>
            {getFieldDecorator('depositBank', {
              initialValue: item.depositBank,
            })(<Input />)}
          </Form.Item>
        </Form>
      </Modal>
    )
  }
}
