import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import { Badge, Popover, Icon } from 'antd';
import SelectModal from '../../../components/SelectModal';
import styles from './support.less';
import { Codes } from '../../../utils/config';

export default class SupportSelectSortModal extends PureComponent {
  static propTypes = {
    selTableData: PropTypes.array.isRequired,
    modalVisible: PropTypes.bool.isRequired,
    rowKeyName: PropTypes.string.isRequired,
  };

  render() {
    const { selTableData, modalVisible, rowKeyName, onCancel, onOk, onSearch, ...fsTableOpts } = this.props;

    const modalProps = {
      title: '选则相关配套',
      maskClosable: false,
      visible: modalVisible,
      onCancel,
      onOk,
    };

    const searchProps = {
      searchField: 'name',
      searchKeyWord: '',
      searchSize: 'default',
      searchSelect: true,
      searchSelectOptions: [{
        value: 'name', name: '配套名称', mode: 'input',
      },{
        value: 'code', name: '配套编号', mode: 'input',
      }],
      searchSelectProps: {
        defaultValue: 'name',
      },
      onSearch: (value) => {
        onSearch(value);
      },
    };

    const selTableProps = {
      operDel: true,
      operSort: true,
      tableClassName: styles.sTable,
      tablePagination: false,
      tableDataSource: selTableData,
      rowKeyName: rowKeyName,
      tableColumns: [{
        title: '配套编号',
        dataIndex: 'code',
        key: 'code',
      },{
        title: '配套名称',
        dataIndex: 'name',
        key: 'name',
      }],
    };

    //待选资源Table属性
    const fsTableProps = {
      fsTableClassName: styles.fsTable,
      fsTableColumns: [{
        title: '配套编号',
        dataIndex: 'code',
        key: 'code',
      },{
        title: '配套名称',
        dataIndex: 'name',
        key: 'name',
      }],
      ...fsTableOpts,
    }

    return (
      <SelectModal
        mode="multiple"
        { ...searchProps }
        { ...modalProps }
        { ...selTableProps }
        { ...fsTableProps }
      />
    );
  }
}
