import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import { Spin, Card, Form, Switch, Radio, Button, Input } from 'antd';
import { domains, Codes } from '../../../utils/config';

@Form.create()
export default class BaseInfoCard extends PureComponent {
  static propTypes = {
    form: PropTypes.object.isRequired,
    item: PropTypes.object.isRequired,
    loading: PropTypes.bool.isRequired,
    onSubmit: PropTypes.func.isRequired,
    onCancel: PropTypes.func.isRequired,
  };

  handleSubmit = (e) => {
    e.preventDefault();
    const { form, onSubmit } = this.props;
    const { getFieldsValue, validateFields } = form;
    validateFields((errors) => {
      if (errors) return;
      const data = { ...getFieldsValue() };
      onSubmit(data);
    });
  }

  render() {
    const { form: { getFieldDecorator }, item, loading, onCancel } = this.props;

    const formItemLayout = {
      labelCol: {
        xs: { span: 24 },
        sm: { span: 7 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 12 },
        md: { span: 10 },
      },
    };

    const submitFormLayout = {
      wrapperCol: {
        xs: { span: 24, offset: 0 },
        sm: { span: 10, offset: 7 },
      },
    };

    return (
      <Spin spinning={loading}>
        <Card>
          <Form layout="horizontal" onSubmit={this.handleSubmit}>
            <Form.Item label="厂商编号" hasFeedback {...formItemLayout}>
              {getFieldDecorator('code',{
                rules: [{ required: true, type: 'string', message: '编号为必填写!' }],
                initialValue: item.code,
              })(<Input />)}
            </Form.Item>
            <Form.Item label="厂商名称" hasFeedback {...formItemLayout}>
              {getFieldDecorator('name',{
                rules: [{ required: true, type: 'string', message: '名称为必填项!' }],
                initialValue: item.name,
              })(<Input />)}
            </Form.Item>
            <Form.Item label="厂商类型" {...formItemLayout}>
              {getFieldDecorator('domain',{
                initialValue: item.domain || Codes.CODE_PJ,
              })(
                <Radio.Group>
                  {Object.keys(domains).map(key =>
                    <Radio value={Number(key)} key={`domain-${key}`}>{domains[Number(key)]}</Radio>
                  )}
                </Radio.Group>
              )}
            </Form.Item>
            <Form.Item label="联系人" hasFeedback {...formItemLayout}>
              {getFieldDecorator('contactName',{
                initialValue: item.contactName,
              })(<Input />)}
            </Form.Item>
            <Form.Item label="联系电话" hasFeedback {...formItemLayout}>
              {getFieldDecorator('mobile',{
                initialValue: item.mobile,
              })(<Input />)}
            </Form.Item>
            <Form.Item label="开户银行" hasFeedback {...formItemLayout}>
              {getFieldDecorator('depositBank',{
                rules: [{ required: true, type: 'string', message: '开户行为必填项!' }],
                initialValue: item.depositBank,
              })(<Input />)}
            </Form.Item>
            <Form.Item label="银行账户" hasFeedback {...formItemLayout}>
              {getFieldDecorator('bankAccount',{
                rules: [{ required: true, type: 'string', message: '账户为必填项!' }],
                initialValue: item.bankAccount,
              })(<Input />)}
            </Form.Item>
            <Form.Item label="营业执照编号" hasFeedback {...formItemLayout}>
              {getFieldDecorator('licenseId',{
                initialValue: item.licenseId,
              })(<Input />)}
            </Form.Item>
            <Form.Item label="纳税人识别号" hasFeedback {...formItemLayout}>
              {getFieldDecorator('taxNumber',{
                initialValue: item.taxNumber,
              })(<Input />)}
            </Form.Item>
            <Form.Item label="发票类型" {...formItemLayout}>
              {getFieldDecorator('receiptType', {
                initialValue: item.receiptType || 'SPECIAL',
              })(
                <Radio.Group>
                  <Radio value="COMMON" key="receipt-com">普通发票</Radio>
                  <Radio value="SPECIAL" key="receipt-spl">增值税发票</Radio>
                </Radio.Group>
              )}
            </Form.Item>
            <Form.Item {...submitFormLayout} style={{ marginTop: 32 }}>
              <Button onClick={onCancel}>取消</Button>
              <Button type="primary" style={{ marginLeft: 35 }} htmlType="submit">提交</Button>
            </Form.Item>
          </Form>
        </Card>
      </Spin>
    );
  }
}
