import React, { Component } from 'react';
import { connect } from 'dva';
import { routerRedux } from 'dva/router';
import queryString from 'query-string';
import { Card, Modal, Steps, Badge, Button, Table, Divider, Icon } from 'antd';
import moment from 'moment';
import PageHeaderLayout from '../../../layouts/PageHeaderLayout';
import FooterToolbar from '../../../components/FooterToolbar';
import { Codes, orderStatuses, productType, orderSplitStatus } from '../../../utils/config';
import { provCodeToName } from '../../../utils/city';

@connect(state => ({ orderDetail: state.orderDetail }))
export default class SubOrderProfile extends Component {
  handlePageCancel = () => {
    const { filters, dispatch } = this.props;
    dispatch(routerRedux.push({
      pathname: '/trade/order',
      search: queryString.stringify(filters),
    }));
  }

  // handleOrderStatus = (id, type, name) => {
  //   const { dispatch, orderDetail } = this.props;
  //   const { filters } = orderDetail;
  //   Modal.confirm({
  //     title: name,
  //     cancelText: '取消',
  //     okText: '确认',
  //     onOk: () =>
  //       dispatch({
  //         type: `orderDetail/${type}`,
  //         payload: { id },
  //         callback: () => {
  //           dispatch(routerRedux.push(`/trade/order/sub/profile/${id}`));
  //         },
  //       }),
  //   });
  // }

  // nextStepOperation = (data) => {
  //   const { orderStatus, id } = data;
  //   switch (orderStatus) {
  //     case Codes.CODE_UNPAID:
  //       return (
  //         <Button
  //           type="primary"
  //           onClick={() =>
  //             this.handleOrderStatus(id, 'orderPay', '确定支付该订单?')}
  //         >立即支付
  //         </Button>
  //       );
  //       break;
  //     case Codes.CODE_COMPLETE:
  //       return null;
  //       break;
  //     case Codes.CODE_CANCEL:
  //       return null;
  //       break;
  //     default:
  //       return (
  //         <Button
  //           type="primary"
  //           disabled={true}
  //         >进行中</Button>
  //       );
  //       break;
  //   }
  // }

  render() {
    const { orderDetail } = this.props;
    const { currentItem } = orderDetail;
    const {
      id,
      code,
      gmtCreated,
      userCode,
      status,
      provinceCode,
      cityName,
      zoneName,
      classroomName,
      orderStatus,
      splitStatus,
      merchantName,
      originPrice,
      finalPrice,
      adjustPrice,
      name,
      type,
      mobile,
      address,
      note,
      goods,
    } = currentItem;

    // simply table columns
    const simplyTableColumns = [{
      title: 'field',
      dataIndex: 'field',
      key: 1,
      width: '20%',
    },{
      title: 'value',
      dataIndex: 'value',
      key: 2,
      width: '80%',
    }];
    // 订单信息 - table data
    const orderInfoTableDatas = [{
      field: '订单编号',
      value: id,
      key: 1,
    },{
      field: '下单时间',
      value: moment(gmtCreated).format('YYYY-MM-DD HH:mm:ss'),
      key: 2,
    },{
      field: '订单状态',
      value: orderStatuses[orderStatus],
      key: 3,
    },{
      field: '拆分状态',
      value: orderSplitStatus[splitStatus],
      key: 4,
    },{
      field: '拆分原因',
      value: '订单中包含实体物品或物品分属不同商家',
      key: 5,
    }];
    // 收货人信息 - table data
    const consumerInfoTableData = [{
      field: '购买终端编号',
      value: userCode,
      key: 1,
    },{
      field: '购买终端名称',
      value: `${classroomName}`,
      key: 2,
    },{
      field: '终端所属校区',
      value: `${provCodeToName(provinceCode)}-${cityName}-${zoneName}`,
      key: 3,
    },{
      field: '终端所属渠道',
      value: merchantName,
      key: 4,
    },{
      field: '收货人姓名',
      value: name,
      key: 5,
    },{
      field: '收货人电话',
      value: mobile,
      key: 6,
    },{
      field: '收货地址',
      value: address,
      key: 7,
    }];
    // 商品清单
    const goodsTableColumns = [{
      title: '商品编号',
      dataIndex: 'code',
      key: 1,
      width: '20%',
    },{
      title: '商品名称',
      dataIndex: 'name',
      key: 2,
      width: '20%',
    },{
      title: '商品类型',
      dataIndex: 'type',
      render: (text, row) => productType[text],
      key: 3,
      width: '15%',
    },{
      title: '商品售价(元)',
      dataIndex: 'merchantPrice',
      key: 4,
      width: '20%',
    },{
      title: '商品数量',
      dataIndex: 'quantity',
      key: 5,
      width: '10%',
    },{
      title: '操作',
      dataIndex: 'operation',
      render: (text, row) => <a>查看详情</a>,
      key: 6,
      width: '15%',
    }];
    // 子订单列表
    const subOrderTableColumns = [{
      title: '子订单编号',
      dataIndex: 'id',
      key: 1,
      width: '20%',
    }];
    // 结算信息 - table data
    const strs = [];
    (goods || []).forEach(item => strs.push(`${item.merchantPrice}(元) * ${item.quantity}`));
    const accountTableDatas = [{
      field: '商品总价',
      value: `${strs.join(' + ')} = ${originPrice}(元)`,
      key: 1,
    },{
      field: '支付金额',
      value:
        <span>
          {`总价：${originPrice}(元) - 商品优惠：${adjustPrice}(元) = 订单总金额：`}
          <strong style={{ color: 'red' }}>{`${finalPrice}(元)`}</strong>
        </span>,
      key: 2,
    }]

    const entityStepMap = {
      [Codes.CODE_UNPAID]: 0,
      [Codes.CODE_PAID]: 1,
      [Codes.CODE_FORSEND]: 1,
      [Codes.CODE_SENT]: 2,
      [Codes.CODE_RECEIVED]: 3,
      [Codes.CODE_CANCEL]: 4,
      [Codes.CODE_COMPLETE]: 4,
    };
    const virtualStepMap = {
      [Codes.CODE_UNPAID]: 0,
      [Codes.CODE_PAID]: 1,
      [Codes.CODE_FORSEND]: 1,
      [Codes.CODE_SENT]: 1,
      [Codes.CODE_RECEIVED]: 1,
      [Codes.CODE_CANCEL]: 4,
      [Codes.CODE_COMPLETE]: 4,
    };

    return (
      <PageHeaderLayout title="子订单详情">
        {type == Codes.CODE_ENTITY ?
          <Card title="订单状态" bordered={false} style={{ marginBottom: 20 }}>
            <Steps current={entityStepMap[orderStatus]}>
              <Steps.Step title="提交订单" icon={<Icon type="schedule" />} />
              <Steps.Step title="付款成功" icon={<Icon type="red-envelope" />} />
              <Steps.Step title="商品出库" icon={<Icon type="inbox" />} />
              <Steps.Step title="等待收货" icon={<Icon type="rocket" />} />
              <Steps.Step title="完成" icon={<Icon type="check" />} />
            </Steps>
          </Card>
        :
          <Card title="订单状态" bordered={false} style={{ marginBottom: 20 }}>
            <Steps current={virtualStepMap[orderStatus]}>
              <Steps.Step title="提交订单" icon={<Icon type="schedule" />} />
              <Steps.Step title="付款成功" icon={<Icon type="red-envelope" />} />
              <Steps.Step title="完成" icon={<Icon type="check" />} />
            </Steps>
          </Card>
        }
        <Card title="商品清单" bordered={false} style={{ marginBottom: 20 }}>
          <Table
            size="small"
            rowKey={record => record.id}
            columns={goodsTableColumns}
            dataSource={goods || []}
            bordered={true}
            pagination={false}
          />
        </Card>
        <Card title="收货人信息" bordered={false} style={{ marginBottom: 20 }}>
          <Table
            size="small"
            columns={simplyTableColumns}
            dataSource={consumerInfoTableData}
            bordered={true}
            pagination={false}
            showHeader={false}
          />
        </Card>
        <Card title="订单备注" bordered={false} style={{ marginBottom: 20 }}>
          {note ? note : '无'}
        </Card>
        <Card title="结算信息" bordered={false}>
          <Table
            size="small"
            columns={simplyTableColumns}
            dataSource={accountTableDatas}
            bordered={true}
            pagination={false}
            showHeader={false}
          />
        </Card>
        <FooterToolbar>
          <Button onClick={this.handlePageCancel} type="primary">返回订单列表</Button>
        </FooterToolbar>
      </PageHeaderLayout>
    );
  }
}
