import React, { Component } from 'react';
import { Card, List, Row, Col, Button } from 'antd';
import moment from 'moment';
import PageHeaderLayout from '../../../layouts/PageHeaderLayout';
import { Codes, orderStatuses, goodsType } from '../../../utils/config';
import styles from './list.less';

export default class OrderStandardList extends Component {

  render() {
    const { onViewItem, onChange, pagination, dataSource, loading } = this.props;
    const newPagination = { ...pagination, onChange };

    const OrderItem = ({content, viewable}) => {
      const operation = () => {
        if (content.orderStatus == Codes.CODE_UNPAID) {
          return (
            <div>
              <Button type="primary">立即支付</Button>
            </div>
          );
        } else if (content.orderStatus !== Codes.CODE_COMPLETE){
          return (
            <div>
              <Button type="primary" disabled={true}>处理中...</Button>
            </div>
          );
        } else {
          return (
            <div>已完成</div>
          );
        }
      }
      return (
        <div className={styles.itemWrapper}>
          <div className={styles.itemHeader}>
            <div className={styles.time}>{moment(content.gmtCreated).format('YYYY-MM-DD HH:mm:ss')}</div>
            <div className={styles.code}>{`订单号：${content.id}`}</div>
            <div className={styles.status}>{`订单状态：${orderStatuses[content.orderStatus]}`}</div>
          </div>
          <div className={styles.itemBody}>
            <div className={styles.goodsInfo}>
              {'商品类型：' + goodsType[content.type] ? goodsType[content.type] : '未知' }
            </div>
            <div className={styles.userInfo}>
              <ul>
                <li>{`收货人：${content.name}`}</li>
                <li>{`联系电话：${content.mobile}`}</li>
                <li>{`收货地址：${content.address}`}</li>
              </ul>
            </div>
            <div className={styles.jump}>
              <a disabled={!viewable ? true : false} onClick={() => onViewItem({ id: content.id })}>订单详情</a>
            </div>
            <div className={styles.change}>
              {operation()}
            </div>
          </div>
        </div>
      );
    }

    const splitedOrderRowMaker = (item) => {
      // 未付款
      if (item.orderStatus == Codes.CODE_UNPAID) {
        return (
          <OrderItem key={item.id} content={item} viewable={true}/>
        );
      // 已付款 需要拆单的(显示主订单及子订单)
      } else {
        return (
          <div className={styles.orderItemWrapper}>
            <div className={styles.rowHeader}>
              <div className={styles.row1}>
                <div className={styles.time}>{moment(item.gmtCreated).format('YYYY-MM-DD HH:mm:ss')}</div>
                <div className={styles.code}>{`订单号：${item.id}`}</div>
                <div className={styles.desc}>订单内包含实体物品或者供应商不同，故拆分成以下订单</div>
              </div>
              <div className={styles.row2}>
                <div className={styles.receiver}>{`收货人：${item.name}`}</div>
                <div className={styles.price}>{`订单金额：${item.finalPrice}(元)`}</div>
                <div className={styles.status}>{`订单状态：${orderStatuses[item.orderStatus]}`}</div>
                <div className={styles.operation}>
                  <a onClick={() => onViewItem({ id: item.id })}>{`查看拆单详情>`}</a>
                </div>
              </div>
            </div>
            <div className={styles.subOrder}>
              {item.detailList.map(one => <OrderItem key={one.id} content={one} viewable={false}/>)}
            </div>
          </div>
        );
      }
      // 已付款 不需要拆单的(实际都会拆单)不显示主订单了
      // } else {
      //   return (
      //     <div className={styles.common}>
      //       {item.detailList.map(one => <OrderItem key={one.id} content={one} viewable={true}/>)}
      //     </div>
      //   );
      // }
    };

    return (
      <List
        size="large"
        rowKey="id"
        split={false}
        loading={loading}
        pagination={newPagination}
        dataSource={dataSource}
        renderItem={item => (
          <List.Item
            key={item.id}
          >
            {splitedOrderRowMaker(item)}
          </List.Item>
        )}
      />
    );
  }
}
