import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import { Badge } from 'antd';
import SelectModal from '../../../components/SelectModal';
import { Codes, tagType, statuses } from '../../../utils/config';

export default class TagSortModal extends PureComponent {
  static propTypes = {
    tagList: PropTypes.array.isRequired,
    modalVisible: PropTypes.bool.isRequired,
    rowKeyName: PropTypes.string.isRequired,
  };

  render() {
    const { tagList, modalVisible, rowKeyName, onCancel, onOk } = this.props;
    const modalProps = {
      title: '标签排序',
      maskClosable: false,
      visible: modalVisible,
      destroyOnClose: true,
      onCancel,
      onOk,
    };
    const selTableProps = {
      operSort: true,
      tablePagination: false,
      tableDataSource: tagList,
      rowKeyName: rowKeyName,
      tableColumns: [{
        title: '位置',
        dataIndex: 'sort',
        key: 'sort',
        render: (text, record, index) => index + 1,
      },{
        title: '标签名称',
        dataIndex: 'name',
        key: 'name',
      },{
        title: '标签状态',
        dataIndex: 'status',
        key: 'status',
        render: (text, record) => {
          const statusMap = {[Codes.CODE_NORMAL]: 'success', [Codes.CODE_DELETE]: 'error'};
          return (<Badge status={statusMap[record.status]} text={statuses[record.status]} />);
        },
      // },{
      //   title: '标签类型',
      //   dataIndex: 'type',
      //   key: 'type',
      //   render: (text, record) => (<span>{tagType[record.type]}</span>),
      }],
    };

    return (
      <SelectModal
        mode="sort"
        { ...modalProps }
        { ...selTableProps }
      />
    );
  }
}
