import React, { Component } from 'react';
import PropTypes from 'prop-types';
import moment from 'moment';
import classnames from 'classnames';
import queryString from 'query-string';
import { Divider, Table, Modal, Badge } from 'antd';
import AnimTableBody from '../../../components/Animation/AnimTableBody';
import styles from './table.less';
import { Codes, terminalStatuses } from '../../../utils/config';

export default class TerminalTableList extends Component {

  handleOperateItem = (record) => {
    const { onDeleteItem, onRecoverItem } = this.props;
    Modal.confirm({
      title: `您确定要${record.status === Codes.CODE_NORMAL ? '禁用' : '解禁'}该终端账号?`,
      onOk () {
        if (record.status === Codes.CODE_NORMAL) {
          onDeleteItem(record.id);
        } else {
          onRecoverItem({ id: record.id, status: Codes.CODE_NORMAL });
        }
      },
    });
  }

  render() {
    const { onDeleteItem, onEditItem, curStatus, location, pagination, ...tableProps } = this.props;

    // 从url中提取查询参数
    location.query = queryString.parse(location.search);

    const columns = [{
      title: '终端编号',
      dataIndex: 'code',
      key: 'code',
    },{
      title: '终端名称',
      dataIndex: 'name',
      key: 'name',
    },{
      title: '校区',
      dataIndex: 'campusName',
      key: 'campusName',
    },{
      title: '渠道名称',
      dataIndex: 'merchantId',
      key: 'merchantId',
      render: (text, record) => record.merchantName,
    },{
      title: '状态',
      dataIndex: 'status',
      key: 'status',
      render: (text, record) => {
        const statusMap = {[Codes.CODE_NORMAL]: 'success', [Codes.CODE_DISABLE]: 'error'};
        return (<Badge status={statusMap[record.status]} text={terminalStatuses[record.status]} />);
      },
      filters: Object.keys(terminalStatuses).map(key => ({ text: terminalStatuses[key], value: key })),
      filterMultiple: false,
      filteredValue: [curStatus],
    },{
      title: '修改时间',
      dataIndex: 'gmtModified',
      key: 'gmtModified',
      render: (text, record) => (
        <div>{moment(text).format('YYYY-MM-DD HH:mm:ss')}</div>
      )
    },{
      title: '操作',
      dataIndex: 'operation',
      key: 'operation',
      render: (text, record) => (
        <div>
          <a onClick={() => onEditItem(record)}>编辑</a>
          <Divider type="vertical" />
          <a onClick={() => this.handleOperateItem(record)}>{record.status === Codes.CODE_NORMAL ? '禁用' : '解禁'}</a>
        </div>
      )
    }];

    columns.map(item => {
      item.dataIndex === 'status' && !curStatus ? delete item.filteredValue : null;
    });

    // 配置分页
    tableProps.pagination = !!pagination && { ...pagination, showSizeChanger: true, showQuickJumper: true, showTotal: total => `共 ${total} 条`};

    // 添加动画
    const AnimationTableBody = (props) => (<AnimTableBody {...props}/>);

    return (
      <Table
        simple
        bordered
        { ...tableProps }
        columns={columns}
        className={classnames({ [styles.table]: true, [styles.motion]: true })}
        rowKey={record => record.id}
        components={{
          body: { wrapper: AnimationTableBody }
        }}
      />
    );
  }
}
